<?php

/*
 *   W-AGORA
 *   -------
 *   File:	oracle8.php3
 *   Usage:	include file - Database access functions (Oracle 8)
 *   Date:	may 12, 2000
 *   Oracle8 additions by:  Andrew Okhmat <andy@crgu.com>
 */

if (!defined("_DBACCESS")) {
	include ("$inc_dir/dbaccess.$ext");
}

class oracle8_access extends DBaccess {

var $dbname;

function OpenDB () {
	global $dbhost, $dbuser, $dbpassword, $dbname;

	$this->dblink = OCIPLogon($dbuser, $dbpassword, $dbhost);
	if (!$this->dblink) {
		echo "Oracle8 error: ".OCIError($this->dblink)."<BR>";
		return -3;
	}
	$this->dbname = $dbname;
	return 0;
}

function createForum ($table, $password) {
	global $bn_var, $db_var;
	global $bn_var_size;

	/* Check if table exists */
	if ($this->OCI_parse_exec($this->dblink,$result,"select count(table_name) from user_tables where table_name=upper('$table')"))
		return (-3);
	OCIFetch($result);
	$found=OCIResult($result,1);
	OCIFreeStatement($result);
	if ($found<>0) {
                return (-1); /*  table already exist */
        }

	/* Create Table */
	$desc = "cle NUMBER NOT NULL PRIMARY KEY";
	$desc .= ", parent NUMBER";
	$desc .= ", childs NUMBER";
	$desc .= ", thread NUMBER";
	$desc .= ", newest NUMBER";
	$values = "0, 0, 0, 0, 0";
	$unixdate = time();
	$count = Count ($bn_var);
	$i=0;
	while ($i < $count) {
		$col = $bn_var[$i];
		$val = $$col;
		$sz = $bn_var_size[$col];
		if ($sz == "INT") {
			$desc .= ", $col NUMBER";
			$values .= ", " . IntVal($val);
		}
		elseif ($sz == "BLOB") {
			$desc .= ", $col VARCHAR(4000)";
			$values .= ", '$val'";
		}
		else {
			$desc .= ", $col VARCHAR2($sz)";
			$values .= ", '$val'";
		}
		$i++;
	}
	$count = Count ($db_var);
	$i=0;
	while ($i < $count) {
		$col = $db_var[$i];
		$val = $$col;
		$sz = $bn_var_size[$col];
		if ($sz == "INT") {
			$desc .= ", $col NUMBER";
			$values .= ", " . IntVal($val);
		}
		elseif ($sz == "BLOB") {
			$desc .= ", $col VARCHAR(4000)";
			$values .= ", '$val'";
		}
		else {
			$desc .= ", $col VARCHAR2($sz)";
			$values .= ", '$val'";
		}
		$i++;
	}
	if ($this->OCI_parse_exec($this->dblink, $result, "CREATE TABLE $table ($desc)"))
		return (-3);
	OCIFreeStatement($result);

	if ($this->OCI_parse_exec($this->dblink, $result, "INSERT INTO $table VALUES($values)"))
		return (-3);
	OCIFreeStatement($result);
	return (0);
}

function deleteForum ($forum, $password) {
	$forum_passwd = $this->GetPassword($forum);
	if ($password != $forum_passwd) return (-2); /* invalid password */

	if ($this->OCI_parse_exec($this->dblink, $result, "DROP TABLE $forum"))
		return (-3); /* access problem */
	OCIFreeStatement($result);
	return (0);
}

function getPassword ($forum) {
	$password="";
	$this->OCI_parse_exec($this->dblink, $result, "SELECT password FROM $forum WHERE cle=0");
	if (OCIFetch($result)) $password = OCIResult ($result, 1);
	OCIFreeStatement($result);
	return ($password);
}

function changePassword ($forum, $old_pass, $new_pass) {
	$forum_passwd = $this->GetPassword($forum);
	if ($old_pass != $forum_passwd) return (-2); /* invalid password */

	if ($this->OCI_parse_exec($this->dblink, $result, "UPDATE $forum SET password='$new_pass' WHERE cle=0"))
		return (-3); /* access problem */
	OCIFreeStatement($result);
	return (0);
}

function listThreads ($forum, $first=0, $last=0) {
	global $bn_maxthreads, $list_var;

	$bn_maxthreads = (isSet($bn_maxthreads) ) ? $bn_maxthreads : 0;
	settype ($bn_maxthreads, "integer");
	settype ($first, "integer");
	settype ($last, "integer");

#	1) gets total count # of notes
#	------------------------------
	if ($this->OCI_parse_exec($this->dblink, $result,"SELECT count(*) as total FROM $forum WHERE cle<>0"))
		return (-3);
	OCIFetch($result);
	$ret["total"] = OCIResult ($result, 1);
	OCIFreeStatement($result);
	if ($ret["total"] == 0) return ($ret);

#	2) Find the first (and last) thread to be displayed in the page
#	and gets number of notes per thread
#	----------------------------------------------------------------
	if (!$last) {
		$order="DESC";
		$last=1;
	} else {
		$order="ASC";
	}

	$where = "thread>=$last"; // $last default to 1: don't display key 0
	if ($first>0) {
		$where .= " AND thread<=$first";
	}

	$limit = (empty($bn_maxthreads)) ? "" : "LIMIT $bn_maxthreads";

	$query = "SELECT thread, count(*) FROM $forum WHERE $where GROUP BY thread ORDER BY thread $order $limit";
	if ($this->OCI_parse_exec($this->dblink, $result,"$query"))
		return (-3);
	$tcount=0;
	while (OCIFetch($result)) {
		$tcount++;
		$resultrow[$tcount][1] = OCIResult($result,1);
		$resultrow[$tcount][2] = OCIResult($result,2);
	}
	OCIFreeStatement($result);

	if ($tcount > 0) {
		if ($order=="DESC") {
			$tfirst  = $resultrow[1][1];
			$tlast = $resultrow[$tcount][1];
		} else {
			$tlast  = $resultrow[1][1];
			$tfirst = $resultrow[$tcount][1];
		}

		for ($i=1; $i<=$tcount; $i++) {
			$t = $resultrow[$i][1];
			$replies[$t] = $resultrow[$i][2] - 1;
		}
		unset ($resultrow);
	}

	$ret["threads"]=$tcount; // number of threads displayed
	$ret["first"]=$tfirst;
	$ret["last"]=$tlast;

	if ($tcount < 1) {
		$ret["next"] = 0;
		$ret["prev"] = 0;
		return $ret;
	}
	
#	3) gets all threads
#	-------------------

	$where = "thread<=$tfirst AND thread>=$tlast";

	$cols = "cle as \"cle\",parent as \"parent\",childs as \"childs\",thread as \"thread\",newest as \"newest\"";
	while (list($var,$val) = each($list_var)) {
		if ($val==1) $cols.=",$var as \"$var\"";
	}

	if ($this->OCI_parse_exec($this->dblink, $result,"SELECT $cols FROM $forum WHERE $where ORDER BY thread DESC,cle ASC"))
		return (-3);

	reset ($this->entries);
	reset ($this->children);
	$ncount=0;
	while (OCIFetchInto($result,$row,OCI_ASSOC)) {
		$key = (int) $row["cle"];
		$parent = (int) $row["parent"];
		if ($parent==0) {
			$row["replies"] = $replies[$key];
		}
		if (!empty($row["bn_name"])) {
			$table = $row["bn_name"];
			if (!$this->OCI_parse_exec($this->dblink, $r2,"select count(*) as notes_count, max(unixdate) as last_note from $table")) {
				OCIFetch($r2);
				$row["notes_count"]  = OCIResult ($r2, 1);
				$row["last_note"]  = OCIResult ($r2, 2);
				OCIFreeStatement($r2);
			}
		}
			
		$this->entries[$key] = $row;
		$this->children[$parent][] = $key;
		$ncount++;
	}
	OCIFreeStatement($result);
	$ret["notes"]=$ncount;	// number of notes displayed
	
#	4) gets next/previous count
#	---------------------------
	if ($this->OCI_parse_exec($this->dblink, $result,"SELECT count(*) AS prev FROM $forum WHERE thread>$tfirst"))
		return (-3);
	OCIFetch($result);
	$ret["prev"]  = OCIResult ($result, 1);
	OCIFreeStatement($result);

	if ($this->OCI_parse_exec($this->dblink, $result,"SELECT count(*) AS next FROM $forum WHERE cle<> 0 AND thread<$tlast"))
		return (-3);
	OCIFetch($result);
	$ret["next"]  = OCIResult ($result, 1);
	OCIFreeStatement($result);
		
	return $ret;
}

function listNotes ($forum, $first=0, $last=0, $sort="", $where="") {
	echo "<BR>notes<BR>";
	global $bn_maxthreads, $list_var;

	$bn_maxthreads = 0; //Dirty HACK
	$bn_maxthreads = (isSet($bn_maxthreads) ) ? $bn_maxthreads : 0;
	settype ($bn_maxthreads, "integer");
	settype ($first, "integer");
	settype ($last, "integer");

#	1) gets total count # of notes
#	------------------------------
	if ($this->OCI_parse_exec($this->dblink, $result,"SELECT count(*) as total FROM $forum WHERE cle<>0"))
		return (-3);

	OCIFetch($result);
	$ret["total"] = OCIResult ($result, 1);
	if ($ret["total"] == 0) return $ret;
	OCIFreeStatement($result);

#	2) gets all notes sorted by $sort
#	---------------------------------
	$whereClause = "WHERE cle>0"; // skip administrative record
	
	if (!empty($where)) {
		$whereClause .= " AND $where";
		$this->OCI_parse_exec($this->dblink, $result,"SELECT count(*) FROM $forum $whereClause");
		OCIFetch($result);
		$ret["nquery"] = OCIResult ($result, 1);
		OCIFreeStatement($result);
	} else {
		$ret["nquery"] = $ret["total"];
	}
	
	$orderClause = (empty ($sort)) ? "" : " ORDER BY $sort";
	$limit="";
	
	if ($bn_maxthreads>0) {
		if ($last > 0) {
			$start = ($last-$bn_maxthreads)+1;
			$start = ($start<0) ? 0 : $start;
		} else {
			$start=$first;
		}
		$limit = "limit $start, $bn_maxthreads";
	} else {
		$start=0;
	}
	
	$cols = "cle as \"cle\",parent as \"parent\",childs as \"childs\",thread as \"thread\",newest as \"newest\"";
	while (list($var,$val) = each($list_var)) {
		if ($val==1) $cols.=",$var as \"$var\"";
	}

	$query = "SELECT $cols FROM $forum $whereClause $orderClause $limit";
	if ($this->OCI_parse_exec($this->dblink, $result,("$query")))
		return (-3);

	reset ($this->entries);
	reset ($this->children);
	$tcount=0;
	while (OCIFetchInto($result,$row,OCI_ASSOC)) {
		$key = $row["cle"];
		$row["parent"]=0;
		if (!empty($row["bn_name"])) {
			$table = $row["bn_name"];
			if (!$this->OCI_parse_exec($this->dblink, $r2,"select count(*) as notes_count, max(unixdate) as last_note from $table")) {
				OCIFetch($r2);
				$row["notes_count"]  = OCIResult ($r2, 1);
				$row["last_note"]  = OCIResult ($r2, 2);
				OCIFreeStatement($r2);
			}
		}
		$this->entries[$key] = $row;
		$this->children[0][] = $key;
		$tcount++;
	}
	OCIFreeStatement($result);

	$ret["threads"]=$tcount;	// number of threads displayed
	$ret["notes"]=$tcount;	// number of notes displayed

#	3) gets next/previous (1 if TRUE)
#	---------------------------------
	$ret["first"] = $start;
	$ret["last"] = $start + $tcount - 1;
	$ret["next"] = ($ret["nquery"] > $ret["last"]+1) ? 1 : 0;
	$ret["prev"] = ($ret["first"] > 1) ? 1 : 0;
	
	return $ret;
}

function getNote ($forum, $key) {
	if ($this->OCI_parse_exec($this->dblink, $result,"SELECT count(cle) FROM $forum WHERE cle=$key"))
		return (-3);
	OCIFetch($result);
	$num = OCIResult($result,1);
	OCIFreeStatement($result);
	if ($num == 0) return (-4);

	$cols="cle as \"cle\"";
	if ($this->OCI_parse_exec($this->dblink, $result,"select column_name||' as \"'||lower(column_name)||'\"' as cols from all_tab_columns where table_name=upper('$forum') and column_name<>'CLE'"))
		return (-3);
	while (OCIFetch($result)) {
		$val = OCIResult($result,1);
		$cols .= ", $val";
	}
	OCIFreeStatement($result);

	if ($this->OCI_parse_exec($this->dblink, $result,"SELECT $cols FROM $forum WHERE cle=$key"))
		return (-3);
	OCIFetchInto($result, $note, OCI_ASSOC);
	OCIFreeStatement($result);
        $cnt = count($note);
	for ($i=0; $i<=$cnt; $i++) {
		$note[$i]=stripslashes($note[$i]);
	}

	$whereclause = "thread > " . $note["thread"];
	if (!$this->OCI_parse_exec($this->dblink, $result,"SELECT min(thread) FROM $forum WHERE $whereclause")) {
		OCIFetch($result);
		$note["tprev"]= OCIResult($result,1);
		OCIFreeStatement($result);
	}
	
	$whereclause = "thread < " . $note["thread"];
	if (!$this->OCI_parse_exec($this->dblink, $result,"SELECT max(thread) FROM $forum WHERE $whereclause")) {
		OCIFetch($result);
		$note["tnext"]= OCIResult($result,1);
		OCIFreeStatement($result);
	}
	return ($note);
}

function getThreadNewest ($forum, $thread) {
 
 	$where="thread=$thread AND cle<>0";
 	if ($this->OCI_parse_exec($this->dblink, $result, "SELECT MAX(unixdate) FROM $forum WHERE $where"))
 		return (-3);
	if (OCIFetch($result)) $newest = OCIResult($result,1);
	OCIFreeStatement($result);
    return $newest;
}

function getThread ($forum, $key, $thread) {

	reset ($this->entries);
	reset ($this->children);

	$cols="cle as \"cle\"";
	if ($this->OCI_parse_exec($this->dblink, $result,"select column_name||' as \"'||lower(column_name)||'\"' as cols from all_tab_columns where table_name=upper('$forum') and column_name<>'CLE'"))
		return (-3);
	while (OCIFetch($result)) {
		$val = OCIResult($result,1);
		$cols .= ", $val";
	}
	OCIFreeStatement($result);

	$where="thread=$thread AND cle<>0";
	if ($this->OCI_parse_exec($this->dblink, $result, "SELECT $cols FROM $forum WHERE $where ORDER BY cle"))
		return (-3);

	while (OCIFetchInto($result,$row,OCI_ASSOC)) {
		$key = $row["cle"];
		$parent = $row["parent"];
		$this->entries[$key] = $row;
		$this->children[$parent][] = $key;
	}

	OCIFreeStatement($result);
	return 0;
}

function insertNote ($forum, $key, $fields) {
	$ret = $this->insert ($forum, $key, 0, $key, $fields);
	return $ret;
}

function threadNote ($forum, $key, $parent_key, $fields) {
	if ($this->OCI_parse_exec($this->dblink, $result, "SELECT thread,childs FROM $forum WHERE cle=$parent_key"))
			return (-3); /* access problem */
	if (!OCIFetch($result)) {
		OCIFreeStatement($result);
		return (-4);
	}
	$thread = OCIResult ($result, 1);
	$childs = OCIResult ($result, 2);
	OCIFreeStatement($result);
	$childs++;
	$values = "childs=$childs, thread=$thread";

	if ($this->OCI_parse_exec($this->dblink, $result, "UPDATE $forum SET $values WHERE cle=$parent_key"))
			return (-3); /* access problem */
	OCIFreeStatement($result);

	$newest = $fields["unixdate"];
	if ($this->OCI_parse_exec($this->dblink, $result, "UPDATE $forum SET newest=$newest WHERE thread=$thread"))
			return (-3); /* access problem */
	OCIFreeStatement($result);

	$ret = $this->insert ($forum, $key, $parent_key, $thread, $fields);
	return $ret;
}

function insert ($forum, $key, $parent, $thread, &$note) {
	// Get fields defined in table
	if($this->OCI_parse_exec($this->dblink,$result,"select lower(column_name),data_type from all_tab_columns where table_name=upper('$forum') and column_name<>'CLE'"))
		return (-3); 

	$note["parent"] = $parent;
	$note["childs"] = 0;
	$note["thread"] = $thread;
	$note["newest"] = $note["unixdate"];
	$cols = "cle";
	$values = "$key";

	// gets fields name and type
	while (OCIFetch($result)) {
		$colname = OCIResult($result,1);
		$coltype = OCIResult($result,2);
		$val = addSlashes($note[$colname]);
		if (!empty($val)) {
			$cols .= ", $colname";
			if ($coltype == "NUMBER")
				$values .= ", " . IntVal($val);
			else
				$values .= ", '$val'";
		}
	}
	OCIFreeStatement($result);

	if ($this->OCI_parse_exec($this->dblink, $result, "INSERT INTO $forum ($cols) VALUES($values)"))
		return (-3); 
	OCIFreeStatement($result);
	return ($key);
}

function updateNote ($forum, $key, $passwd, &$fields) {
	if($this->OCI_parse_exec($this->dblink,$result,"SELECT password,parent,childs,thread,newest FROM $forum WHERE cle=$key"))
		return (-3);  /* access error */
	if (!OCIFetch($result)) {
		OCIFreeStatement($result);
		return (-4);
	}    
	$password = OCIResult ($result, 1);
	$admin_password = $this->GetPassword($forum);
	if (($passwd != $password) && ($passwd != $admin_password)) {
		OCIFreeStatement($result);
		return (-2); /* invalid password */
	}

	$fields["parent"] = OCIResult ($result, 2);
	$fields["childs"] = OCIResult ($result, 3);
	$fields["thread"] = OCIResult ($result, 4);
	$fields["newest"] = OCIResult ($result, 5);
	OCIFreeSatement($result);

	$values = "cle=$key";

	if($this->OCI_parse_exec($this->dblink,$result,"select lower(column_name),data_type from all_tab_columns where table_name=upper('$forum')"))
		return (-3); 

	// gets fields name and type
	while (OCIFetch($result)) {
		$colname = OCIResult($result,1);
		$coltype = OCIResult($result,2);
		$val = addSlashes($fields[$colname]);
		if (!empty($val)) {
			$cols .= ", " . $colname;
			if ($coltype == "NUMBER")
				$values .= ", $colname= " . intVal($val);
			else
				$values .= ", $colname= '$val'";
		}
	}
	OCIFreeStatement($result);

	if($this->OCI_parse_exec($this->dblink,$result,"UPDATE $forum SET $values WHERE cle=$key"))
		return (-3); 
	OCIFreeStatement($result);
	return (0);
}

function updateThread($forum, $parent, $newthread) {
	if($this->OCI_parse_exec($this->dblink,$result,"UPDATE $forum SET thread=$newthread WHERE parent=$parent"))
		return (-3);
	OCIFreeStatement($result);

	if($this->OCI_parse_exec($this->dblink,$result,"SELECT cle, childs FROM $forum WHERE parent=$parent"))
		return (-3); 
	
	while (OCIFetchInto ($result,$row)) {
		$key=$row[1];
		$childs=$row[2];
		if ($childs > 0) {
			$this->updateThread ($forum, $key, $newthread);
		}
	}
	OCIFreeStatement($result);
}

function deleteNote ($forum, $key, $pass, $bn_dir_notes) {
	if($this->OCI_parse_exec($this->dblink,$result,"SELECT password,filename,attachment,parent,childs,thread FROM $forum WHERE cle=$key"))
		return (-3);

	if (!OCIFetch($result)) {
		OCIFreeStatement($result);
		return (-4);
	}
	$password = OCIResult ($result, 1);

	$admin_password = $this->GetPassword($forum);
	if (($pass != $password) && ($pass != $admin_password)):
		OCIFreeStatement($result);
		return (-2); /* invalid password */
	endif;

 	$filename = OCIResult ($result, 2);
 	$attachment = OCIResult ($result, 3);
 	$parent = OCIResult ($result, 4);
 	$childs = OCIResult ($result, 5);
 	$thread = OCIResult ($result, 6);
	OCIFreeStatement($result);

	// delete note
	if($this->OCI_parse_exec($this->dblink,$result,"DELETE FROM $forum WHERE cle=$key"))
		return (-3);
	OCIFreeStatement($result);

	if ($parent > 0) {
		// decrement childs count in parent
		if($this->OCI_parse_exec($this->dblink,$result,"UPDATE $forum SET childs=childs-1 WHERE cle=$parent"))
			return (-3);
		OCIFreeStatement($result);
	}
	else {
		// update thread value
		if($this->OCI_parse_exec($this->dblink,$result,"SELECT cle, childs FROM $forum WHERE parent=$key"))
			return (-3);
		while (OCIFetchInto($result,$row)) {
			$childkey=$row[1];
			if($this->OCI_parse_exec($this->dblink,$upd,"UPDATE $forum SET thread=$childkey WHERE cle=$childkey")) {
				OCIFreeStatement($result);
				return (-3); 
			}
			OCIFreeStatement($upd);
			if ($row[2] > 0) {
				$this->updateThread ($forum, $childkey, $childkey);
			}
		}
		OCIFreeStatement($result);
	}
	
	// Link children to parent
	if ($childs > 0) {
		if($this->OCI_parse_exec($this->dblink,$result,"UPDATE $forum SET parent=$parent WHERE parent=$key"))
			return (-3);
		OCIFreeStatement($result);
	}

	// update newest in thread
	if ($key != $thread) {
		$newest = $this->getThreadNewest ($forum, $thread);
		if($this->OCI_parse_exec($this->dblink,$result,"UPDATE $forum SET newest=$newest WHERE thread=$thread"))
			return (-3);
		OCIFreeStatement($result);
	}
	
	if (($filename != "none") && is_file("$bn_dir_notes/$filename")) {
 		@unlink ("$bn_dir_notes/$filename");
	}

	if ($attachment && ($attachment != "none") && is_file ("$bn_dir_notes/$key/$attachment") ) {
		@unlink ("$bn_dir_notes/$key/$attachment");
		@rmdir ("$bn_dir_notes/$key");
	}
	return (0);
}

function mDeleteDate ($forum, $from, $to, $passwd, $bn_dir_notes) {
	$admin_password	= $this->getPassword($forum);
	if ($passwd != $admin_password):
		return	(-2); /* invalid password */
	endif;

	$this->OCI_parse_exec($this->dblink,$result,"SELECT cle FROM $forum WHERE cle>=$from AND cle <= $to");
	while (OCIFetch($result)):
		$note = OCIResult ($result, 1);
		$ret = $this->deleteNote($forum, $note, $passwd, $bn_dir_notes);
		if ($ret < 0) { 
			OCIFreeStatement($result);
			return ($ret);
		}
	endwhile;
	OCIFreeStatement($result);
    	return (0);
}

function search ($forum, $pattern, $casesensitive) {
	global $list_var;

	if ($casesensitive) {
		$searcher= "HAVING";
		$expr="REGEXP '.*$pattern.*'";
		$query = "SELECT DISTINCT * FROM $forum $searcher body $expr";
	}
	else {
		$searcher= "WHERE";
		$expr="LIKE '%$pattern%'";
		// set selected columns
		$cols = "cle as \"cle\",parent as \"parent\",childs as \"childs\",thread as \"thread\",newest as \"newest\"";
		while (list($var,$val) = each($list_var)) {
			if ($val==1) $cols.=",$var as \"$var\"";
		}
		$query = "SELECT DISTINCT $cols FROM $forum $searcher body $expr";
	}

	// Get fields defined in table
	if($this->OCI_parse_exec($this->dblink,$result,"select lower(column_name),data_type from all_tab_columns where table_name=upper('$forum')"))
		return (-3); 

	while (OCIFetch($result)) {
		$colname = OCIResult($result,1);
		$coltype = OCIResult($result,2);
		if (($coltype != "NUMBER") && ($colname != "password") && ($colname != "body")) {
			$query .= " OR $colname $expr";
		}
	}
	OCIFreeStatement($result);

	if (!$casesensitive) {
		$query .= " ORDER by thread DESC, cle ASC";
	}

	if($this->OCI_parse_exec($this->dblink,$result,$query))
		return (-3);

	$num = 0;

	reset ($this->entries);
	reset ($this->children);
	while (OCIFetchInto($result,$row,OCI_ASSOC)) {
		$key = $row["cle"];
		$row["parent"]=0;
		$this->entries[$key] = $row;
		$this->children[0][] = $key;
	}
	OCIFreeStatement($result);    

	return $num;
}

function OCI_parse_exec( &$conn, &$stmt, $select ) {

	$stmt = OCIParse($conn, $select);
	if ( !$stmt ) {
	    echo "Oracle error: ".OCIError()."<BR>";
	    OCIFreeStatement($stmt);
	    return 1;
	}
	//echo "$select<BR>";
	if ( !OCIExecute($stmt) ) {
	    echo "Oracle error: ".OCIError()."<BR>";
	    OCIFreeStatement($stmt);
	    return 1;
	}
	return 0;
}

}; // end class

?>
